0.9.9 API documentation: vector_float2.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

vector_float2.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_vec2.hpp"
6
7 namespace glm
8 {
11
15 typedef vec<2, float, defaultp> vec2;
16
18 }//namespace glm
glm::vec2
vec< 2, float, defaultp > vec2
2 components vector of single-precision floating-point numbers.
Definition: vector_float2.hpp:15
glm
Definition: common.hpp:20